package org.devio.rn.splashscreen;

import android.app.Activity;
import android.app.Dialog;
import android.graphics.Color;
import android.os.Build;
import android.view.LayoutInflater;
import android.view.View;

import java.lang.ref.WeakReference;

public class SplashScreen {
    private static Dialog mSplashDialog;
    private static WeakReference<Activity> mActivity;
    private static View view;

    public static void show(final Activity activity, final int themeResId, final String color) {
        if (activity == null) {
            return;
        }
        mActivity = new WeakReference<>(activity);
        activity.runOnUiThread(new Runnable() {
            @Override
            public void run() {
                if (!activity.isFinishing()) {
                    mSplashDialog = new Dialog(activity, themeResId);
                    view = LayoutInflater.from(activity).inflate(R.layout.launch_screen, null);
                    try{
                        int parsedColor = Color.WHITE;
                        if(color != null && color.length() > 0){
                            parsedColor = Color.parseColor(color);
                        }
                        view.setBackgroundColor(parsedColor);
                    } catch (IllegalArgumentException | NullPointerException e){
                        e.printStackTrace();
                    }
                    mSplashDialog.setContentView(view);
                    mSplashDialog.setCancelable(false);

                    if (!mSplashDialog.isShowing()) {
                        mSplashDialog.show();
                    }
                }
            }
        });
    }

    public static void show(final Activity activity, final boolean fullScreen, String color) {
        int resourceId = fullScreen ? R.style.SplashScreen_Fullscreen : R.style.SplashScreen_SplashTheme;
        show(activity, resourceId, color);
    }

    public static void show(final Activity activity) {
        show(activity, false, null);
    }

    public static void show(final Activity activity, String color){
        show(activity, false, color);
    }

    public static void hide(Activity activity) {
        if (activity == null) {
            if (mActivity == null) {
                return;
            }
            activity = mActivity.get();
        }

        if (activity == null) {
            return;
        }

        final Activity _activity = activity;

        _activity.runOnUiThread(new Runnable() {
            @Override
            public void run() {
                if (mSplashDialog != null && mSplashDialog.isShowing()) {
                    boolean isDestroyed = _activity.isDestroyed();

                    if (!_activity.isFinishing() && !isDestroyed) {
                        //thid check is to avoid a blink when dialog will be removed
                        if(view != null){
                            View parent = view.findViewWithTag("parent");
                            if(parent != null){
                                parent.setVisibility(View.GONE);
                            }
                        }
                        mSplashDialog.dismiss();
                    }
                    mSplashDialog = null;
                }
            }
        });
    }
}
